Documentation
¶
Overview ¶
Package london provides a struct for controlling BSS London DSPs. Supported Devices This is a list of devices that BYU currently uses in production, controlled with this driver.
BSS BLU-50 https://bssaudio.com/en/products/blu-50 BSS BLU-100 https://bssaudio.com/en/products/blu-100
This list is not comprehensive.
Index ¶
- type DSP
- func (d *DSP) GetInfo(ctx context.Context) (interface{}, error)
- func (d *DSP) Mutes(ctx context.Context, blocks []string) (map[string]bool, error)
- func (d *DSP) SetMute(ctx context.Context, block string, mute bool) error
- func (d *DSP) SetVolume(ctx context.Context, block string, volume int) error
- func (d *DSP) Volumes(ctx context.Context, blocks []string) (map[string]int, error)
- type Logger
- type Option
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DSP ¶
type DSP struct {
// contains filtered or unexported fields
}
DSP represents a DSP being controlled.
type Logger ¶
type Logger interface {
Debugf(format string, a ...interface{})
Infof(format string, a ...interface{})
Warnf(format string, a ...interface{})
Errorf(format string, a ...interface{})
}
Logger is a logger usable by DSP.
type Option ¶
type Option interface {
// contains filtered or unexported methods
}
Option configures how we create the DSP.
func WithDelay ¶
WithDelay changes the delay between sending commands to the DSP. The default value is 250 milliseconds. See more details about delay in https://github.com/byuoitav/connpool.
func WithLogger ¶
WithLogger adds a logger to DSP. DSP will log appropriate information about the underlying connection and the commands being sent. The default value is nil, meaning that no logs are written.